==> geant4.9.6.p03.tar.gz: EnvPanel.java <==
//$Id: EnvPanel.java,v 1.2 2004/09/24 08:50:51 suzuki Exp $
// 2002 Feb H Yoshida K Awa
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
import java.awt.*;

import java.awt.event.*;

import java.util.*;
import javax.swing.border.*;

import javax.swing.*;

import javax.swing.event.*;
//import javax.swing.JPanel;
//import javax.swing.JTabbedPane;


public class EnvPanel extends JPanel implements ActionListener {

   JTextField[]   textF;     // array for general and special vars

   JLabel[]       textL;     // array for their labels
    //   public String[]       envName;   // array for env names
    //    String[]       initName;  // initial text field values
    //   public String[]       visguibuildName;  // array for Vis/Gui env names
    //   public String[]       visguiuseName; 
   JCheckBox[]    checkB;     // array for VIs, UI BUILDvars
   public   JCheckBox[]    checkU;    // array for USE
         
   JPanel  pane, pane0, pane1, pane2, pane3, pane4;    
   JScrollPane spane;
   JButton reload;
   JTabbedPane twoEnvPanels;
   EnvVariable envVars;

    //public int noenvName;



   static final String envName[] = { 
	"G4SYSTEM", "G4TARGET", "G4INSTALL", "G4WORKDIR", 
	"G4BIN", "G4BINDIR",  "G4TMP",  "G4TMPDIR",
	"G4LIB","G4LIBDIR", "G4BASE", "G4INCLUDE", 
        "G4CLHEP_BASE_DIR","G4USE_STL", "G4DEBUG","G4NO_OPTIMISE",
	"G4EXEC_BUILD", "G4NO_STD_NAMESPACE","G4NO_STD_EXCEPTIONS", 
	"G4_NO_VERBOSE", "G4LIB_BUILD_SHARED","G4LIB_BUILD_STATIC",
	"G4LIB_USE_GRANULAR","G4ANALYSIS_USE", "NeutronHPCrossSections",
	"G4LEDATA","G4LEVELGAMMADATA","G4RADIOACTIVEDATA"};
//
// Geant4 Web page document
//* http://geant4.web.cern.ch/geant4/G4UsersDocuments/UsersGuides/
//                                       ForApplicationDeveloper/html/Appendix/makeFile.htm

   String initName[] = {
       "Linux-g++", "momoExample", "$HOME/Geant4.4.0", "$MOMOWORKDIR",
       "G4BIN", "$G4WORKDIR/$G4SYSTEM/bin", "G4TMP", "G4WORKDIR/$G4SYSTEM/tmp",
       "G4LIB", "$G4WORKDIR/$G4SYSTEM/lib", "G4BASE", "$G4INSTALL/include",
       "/usr/local", "1", "0", "0",
       "ExecBuild", "0", "0",
       "0", "1", "0", 
       "1", "1", "$HOME/data/NeurtonHPX",
       "$HOME/data/LE", "$HOME/data/LGAMMA", "$HOME/data/RadioActive"};

  static final String visguibuildName[]= {
         "G4VIS_BUILD_ASCIITREE_DRIVER",
	"G4VIS_BUILD_DAWN_DRIVER",
	"G4VIS_BUILD_DAWNFILE_DRIVER",
        "G4VIS_BUILD_GAGTREE_DRIVER",
	"G4VIS_BUILD_HEPREPFILE_DRIVER",
        "G4VIS_BUILD_OI_DRIVER",
	"G4VIS_BUILD_OIX_DRIVER", 
	"G4VIS_BUILD_OIWIN32_DRIVER",
	"G4VIS_BUILD_OPACS_DRIVER",
        "G4VIS_BUILD_OPENGL_DRIVER",
	"G4VIS_BUILD_OPENGLWIN32_DRIVER",
	"G4VIS_BUILD_OPENGLX_DRIVER",
        "G4VIS_BUILD_OPENGLXM_DRIVER",
	"G4VIS_BUILD_RAYTRACER_DRIVER",
	"G4VIS_BUILD_VRML_DRIVER",
        "G4VIS_BUILD_VRMLFILE_DRIVER",

	"G4UI_BUILD_XM",
	"G4UI_BUILD_XAW",
	"G4UI_BUILD_WIN32",
        "G4UI_BUILD_WO",
	"G4UI_BUILD_GAG",
	"G4UI_BUILD_TCSH",
	"G4UI_BUILD_TERMINAL1"
}  ;
  static final String visguiuseName[]= {
        "G4VIS_USE_ASCIITREE",
	"G4VIS_USE_DAWN",
	"G4VIS_USE_DAWNFILE",
        "G4VIS_USE_GAGTREE",
	"G4VIS_USE_HEPREPFILE",
        "G4VIS_USE_OI",
	"G4VIS_USE_OIX",
	"G4VIS_USE_OIWIN32",
	"G4VIS_USE_OPACS",
        "G4VIS_USE_OPENGL",
	"G4VIS_USE_OPENGLWIN32",
	"G4VIS_USE_OPENGLX",
        "G4VIS_USE_OPENGLXM",
	"G4VIS_USE_RAYTRACER",
	"G4VIS_USE_VRML",
        "G4VIS_USE_VRMLFILE",

	"G4UI_USE_XM",
	"G4UI_USE_XAW",
	"G4UI_USE_WIN32",
        "G4UI_USE_WO",
	"G4UI_USE_GAG",
	"G4UI_USE_TCSH",
	"G4UI_USE_TERMINAL"
}  ;



//----------------------------------------------------------------------------------------------
public EnvPanel(){
   super();


//      spane = new JScrollPane();
 //        spane.setPreferredSize(new Dimension(850, 700));
     //    spane.setVerticalScrollBar(new JScrollBar());

     pane = new JPanel();    pane.setSize(850,650);
     twoEnvPanels = new JTabbedPane();

     //EnvListener envListener = new EnvListener();  // testing (this) ??
     reload = new JButton("reload");       // for reload/refresh button
      reload.setForeground(Color.red);


      envVars = new EnvVariable();

     pane1 = new JPanel();   pane1.setSize(200, 600);
     pane2 = new JPanel();   pane2.setSize(400, 600);
     pane3 = new JPanel();   pane3.setSize(200, 600);
     pane4 = new JPanel();   pane4.setSize(200, 600);
//
     JPanel pane12 = new JPanel(); pane12.setSize(650, 600);
     JPanel pane34 = new JPanel(); pane34.setSize(500,600);
//   Layout
    this.setLayout(new BorderLayout());

     this.add(reload, "North");
//test     this.add(pane, "Center"); 
    this.add(twoEnvPanels, "Center");


     pane12.setLayout(new FlowLayout(FlowLayout.LEFT));
     pane34.setLayout(new FlowLayout(FlowLayout.LEFT));
     pane1.setLayout(new GridLayout(0,1,5,4));
     pane2.setLayout(new GridLayout(0,1));  
     pane3.setLayout(new GridLayout(0,1));  
     pane4.setLayout(new GridLayout(0,1));  


     //JTextField[] 
     textF = new JTextField[100];
     textL = new JLabel[100];

     //    int noenvName = envName.length;

     for (int i=0; i<envName.length ; i++){   //envName.length ; i++){

//	textF[i] = new JTextField(initName[i]);  // another way of guidance
	 textF[i] = new JTextField(String.valueOf(envVars.get(envName[i]))); //toString notwork
	textL[i] = new JLabel(envName[i]);
      }	

    for (int i=0; i<envName.length; i++){
	pane1.add(textL[i]);
	}
    pane12.add(pane1);

    for (int i=0; i<envName.length; i++){
	pane2.add(textF[i]);
	}
     pane12.add(pane2);	

//test    
     ImageIcon icon = new ImageIcon("yellow-ball.gif");
     twoEnvPanels.addTab("General Envs", icon, pane12);
///////

	 checkB = new JCheckBox[100];
	 checkU = new JCheckBox[100];

     for(int i=0; i<visguibuildName.length; i++){
	if(envVars.get(visguibuildName[i]) == null ){
	    checkB[i] = new JCheckBox(visguibuildName[i]);
	} else {
	    checkB[i] = new JCheckBox(visguibuildName[i], true);
	}
      }

     for(int i=0; i<visguiuseName.length; i++){
	if(envVars.get(visguiuseName[i]) == null){
	    checkU[i] = new JCheckBox(visguiuseName[i]);
	} else {
	    checkU[i] = new JCheckBox(visguiuseName[i], true);
	}
      }

    for (int i=0; i<visguiuseName.length; i++){

	pane3.add(checkU[i]);
	}
     pane34.add(pane3);

    for (int i=0; i<visguibuildName.length; i++){
	pane4.add(checkB[i]);
	}
     pane34.add(pane4);	
     twoEnvPanels.addTab("Vis/Gui Envs", icon, pane34);

     twoEnvPanels.setForegroundAt(0, Color.red);
     twoEnvPanels.setForegroundAt(1, Color.red);

   //  spane.getViewport().add(pane);

      reload.addActionListener(this);   //envListener);


      }

    // public class EnvListener implements ActionListener{

	public void actionPerformed(ActionEvent ae){

	Object o = ae.getSource();

	if( o == reload ){

	    for (int i=0; i<envName.length ; i++){
		textF[i].setText(String.valueOf(envVars.get(envName[i])));
	    }	


     for(int i=0; i<visguibuildName.length; i++){
	if(envVars.get(visguibuildName[i]) == null ){
	    checkB[i].setSelected(false);
	} else {
	    checkB[i].setSelected(true);
	}
      }

     for(int i=0; i<visguiuseName.length; i++){
	if(envVars.get(visguiuseName[i]) == null){
	    checkU[i].setSelected(false);
	} else {
	    checkU[i].setSelected(true);
	}
      }

	    validate();
	}

     }
    //} //EnvListener
 }

==> geant4.10.06.tar.gz: EnvPanel.java <==
//$Id: EnvPanel.java,v 1.2 2004/09/24 08:50:51 suzuki Exp $
// 2002 Feb H Yoshida K Awa
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
import java.awt.*;

import java.awt.event.*;

import java.util.*;
import javax.swing.border.*;

import javax.swing.*;

import javax.swing.event.*;
//import javax.swing.JPanel;
//import javax.swing.JTabbedPane;


public class EnvPanel extends JPanel implements ActionListener {

   JTextField[]   textF;     // array for general and special vars

   JLabel[]       textL;     // array for their labels
    //   public String[]       envName;   // array for env names
    //    String[]       initName;  // initial text field values
    //   public String[]       visguibuildName;  // array for Vis/Gui env names
    //   public String[]       visguiuseName; 
   JCheckBox[]    checkB;     // array for VIs, UI BUILDvars
   public   JCheckBox[]    checkU;    // array for USE
         
   JPanel  pane, pane0, pane1, pane2, pane3, pane4;    
   JScrollPane spane;
   JButton reload;
   JTabbedPane twoEnvPanels;
   EnvVariable envVars;

    //public int noenvName;



   static final String envName[] = { 
	//"G4SYSTEM", "G4TARGET", "G4INSTALL", "G4WORKDIR", 
	//"G4BIN", "G4BINDIR",  "G4TMP",  "G4TMPDIR",
	//"G4LIB","G4LIBDIR", "G4BASE", "G4INCLUDE", 
        //"G4CLHEP_BASE_DIR","G4USE_STL", "G4DEBUG","G4NO_OPTIMISE",
	//"G4EXEC_BUILD", "G4NO_STD_NAMESPACE","G4NO_STD_EXCEPTIONS", 
	//"G4_NO_VERBOSE", "G4LIB_BUILD_SHARED","G4LIB_BUILD_STATIC",
	//"G4LIB_USE_GRANULAR","G4ANALYSIS_USE", 
	"G4LEDATA","G4LEVELGAMMADATA","G4RADIOACTIVEDATA",
        "G4NEUTRONHPDATA" , "G4ABLADATA" ,"G4NEUTRONXSDATA" , "G4PIIDATA" , "G4REALSURFACEDATA", "G4SAIDXSDATA"};
//G4NEUTRONXSDATA
// Geant4 Web page document
//* http://geant4.web.cern.ch/geant4/G4UsersDocuments/UsersGuides/
//                                       ForApplicationDeveloper/html/Appendix/makeFile.htm

   String initName[] = {
       "Linux-g++", "momoExample", "$HOME/Geant4.4.0", "$MOMOWORKDIR",
       "G4BIN", "$G4WORKDIR/$G4SYSTEM/bin", "G4TMP", "G4WORKDIR/$G4SYSTEM/tmp",
       "G4LIB", "$G4WORKDIR/$G4SYSTEM/lib", "G4BASE", "$G4INSTALL/include",
       "/usr/local", "1", "0", "0",
       "ExecBuild", "0", "0",
       "0", "1", "0", 
       "1", "1", "$HOME/data/NeurtonHPX",
       "$HOME/data/LE", "$HOME/data/LGAMMA", "$HOME/data/RadioActive"};

  static final String visguibuildName[]= {
         "G4VIS_BUILD_ASCIITREE_DRIVER",
	"G4VIS_BUILD_DAWN_DRIVER",
	"G4VIS_BUILD_DAWNFILE_DRIVER",
        "G4VIS_BUILD_GAGTREE_DRIVER",
	"G4VIS_BUILD_HEPREPFILE_DRIVER",
        "G4VIS_BUILD_OI_DRIVER",
	"G4VIS_BUILD_OIX_DRIVER", 
	"G4VIS_BUILD_OIWIN32_DRIVER",
	"G4VIS_BUILD_OPACS_DRIVER",
        "G4VIS_BUILD_OPENGL_DRIVER",
	"G4VIS_BUILD_OPENGLWIN32_DRIVER",
	"G4VIS_BUILD_OPENGLX_DRIVER",
        "G4VIS_BUILD_OPENGLXM_DRIVER",
	"G4VIS_BUILD_RAYTRACER_DRIVER",
	"G4VIS_BUILD_VRML_DRIVER",
        "G4VIS_BUILD_VRMLFILE_DRIVER",

	"G4UI_BUILD_XM",
	"G4UI_BUILD_XAW",
	"G4UI_BUILD_WIN32",
        "G4UI_BUILD_WO",
	"G4UI_BUILD_GAG",
	"G4UI_BUILD_TCSH",
	"G4UI_BUILD_TERMINAL1"
}  ;
  static final String visguiuseName[]= {
        "G4VIS_USE_ASCIITREE",
	"G4VIS_USE_DAWN",
	"G4VIS_USE_DAWNFILE",
        "G4VIS_USE_GAGTREE",
	"G4VIS_USE_HEPREPFILE",
        "G4VIS_USE_OI",
	"G4VIS_USE_OIX",
	"G4VIS_USE_OIWIN32",
	"G4VIS_USE_OPACS",
        "G4VIS_USE_OPENGL",
	"G4VIS_USE_OPENGLWIN32",
	"G4VIS_USE_OPENGLX",
        "G4VIS_USE_OPENGLXM",
	"G4VIS_USE_RAYTRACER",
	"G4VIS_USE_VRML",
        "G4VIS_USE_VRMLFILE",

	"G4UI_USE_XM",
	"G4UI_USE_XAW",
	"G4UI_USE_WIN32",
        "G4UI_USE_WO",
	"G4UI_USE_GAG",
	"G4UI_USE_TCSH",
	"G4UI_USE_TERMINAL"
}  ;



//----------------------------------------------------------------------------------------------
public EnvPanel(){
   super();


//      spane = new JScrollPane();
 //        spane.setPreferredSize(new Dimension(850, 700));
     //    spane.setVerticalScrollBar(new JScrollBar());

     pane = new JPanel();    pane.setSize(850,650);
     twoEnvPanels = new JTabbedPane();

     //EnvListener envListener = new EnvListener();  // testing (this) ??
     reload = new JButton("Current DataSet Locations, if empty, source geant4.sh");       // for reload/refresh button
      reload.setForeground(Color.red);


      envVars = new EnvVariable();

     pane1 = new JPanel();   pane1.setSize(200, 600);
     pane2 = new JPanel();   pane2.setSize(400, 600);
     pane3 = new JPanel();   pane3.setSize(200, 600);
     pane4 = new JPanel();   pane4.setSize(200, 600);
//
     JPanel pane12 = new JPanel(); pane12.setSize(650, 600);
     JPanel pane34 = new JPanel(); pane34.setSize(500,600);
//   Layout
    this.setLayout(new BorderLayout());

     this.add(reload, "North");
//test     this.add(pane, "Center"); 
    this.add(twoEnvPanels, "Center");


     pane12.setLayout(new FlowLayout(FlowLayout.LEFT));
     pane34.setLayout(new FlowLayout(FlowLayout.LEFT));
     pane1.setLayout(new GridLayout(0,1,5,4));
     pane2.setLayout(new GridLayout(0,1));  
     pane3.setLayout(new GridLayout(0,1));  
     pane4.setLayout(new GridLayout(0,1));  


     //JTextField[] 
     textF = new JTextField[100];
     textL = new JLabel[100];

     //    int noenvName = envName.length;

     for (int i=0; i<envName.length ; i++){   //envName.length ; i++){

//	textF[i] = new JTextField(initName[i]);  // another way of guidance
	 textF[i] = new JTextField(String.valueOf(envVars.get(envName[i]))); //toString notwork
	textL[i] = new JLabel(envName[i]);
      }	

    for (int i=0; i<envName.length; i++){
	pane1.add(textL[i]);
	}
    pane12.add(pane1);

    for (int i=0; i<envName.length; i++){
	pane2.add(textF[i]);
	}
     pane12.add(pane2);	

//test    
     ImageIcon icon = new ImageIcon("yellow-ball.gif");
     twoEnvPanels.addTab("Env Var Name", icon, pane12);
///////

	 checkB = new JCheckBox[100];
	 checkU = new JCheckBox[100];
/*
     for(int i=0; i<visguibuildName.length; i++){
	if(envVars.get(visguibuildName[i]) == null ){
	    checkB[i] = new JCheckBox(visguibuildName[i]);
	} else {
	    checkB[i] = new JCheckBox(visguibuildName[i], true);
	}
      }

     for(int i=0; i<visguiuseName.length; i++){
	if(envVars.get(visguiuseName[i]) == null){
	    checkU[i] = new JCheckBox(visguiuseName[i]);
	} else {
	    checkU[i] = new JCheckBox(visguiuseName[i], true);
	}
      }

    for (int i=0; i<visguiuseName.length; i++){

	pane3.add(checkU[i]);
	}
     pane34.add(pane3);

    for (int i=0; i<visguibuildName.length; i++){
	pane4.add(checkB[i]);
	}
     pane34.add(pane4);	
     twoEnvPanels.addTab("Vis/Gui Envs", icon, pane34);

     twoEnvPanels.setForegroundAt(0, Color.red);
     twoEnvPanels.setForegroundAt(1, Color.red);

   //  spane.getViewport().add(pane);
*/
      reload.addActionListener(this);   //envListener);


      }

    // public class EnvListener implements ActionListener{

	public void actionPerformed(ActionEvent ae){

	Object o = ae.getSource();
/*
	if( o == reload ){

	    for (int i=0; i<envName.length ; i++){
		textF[i].setText(String.valueOf(envVars.get(envName[i])));
	    }	


     for(int i=0; i<visguibuildName.length; i++){
	if(envVars.get(visguibuildName[i]) == null ){
	    checkB[i].setSelected(false);
	} else {
	    checkB[i].setSelected(true);
	}
      }

     for(int i=0; i<visguiuseName.length; i++){
	if(envVars.get(visguiuseName[i]) == null){
	    checkU[i].setSelected(false);
	} else {
	    checkU[i].setSelected(true);
	}
      }

	    validate();
	}
*/
     }
    //} //EnvListener
 }
